@@ -6,6 +6,3 @@
 #define LT_ELF_MACHINE  EM_ALPHA
 #define LT_ELFCLASS2    ELFCLASS64
 #define LT_ELF_MACHINE2	EM_FAKE_ALPHA
-
-#define PLTs_INIT_BY_HERE NULL
-#define E_ENTRY_NAME      "_start"
