@@ -4,6 +4,3 @@
 
 #define LT_ELFCLASS	ELFCLASS32
 #define LT_ELF_MACHINE	EM_68K
-
-#define PLTs_INIT_BY_HERE NULL
-#define E_ENTRY_NAME    "_start"
