@@ -13,21 +13,21 @@
  * have a bit delay
  */
 
-#define	MAX_DELAY	100000		/* 100000 microseconds = 0.1 seconds */
+#define	MAX_DELAY	100000	/* 100000 microseconds = 0.1 seconds */
 
 /*
  * Returns a file name corresponding to a running pid
  */
-char *
-pid2name(pid_t pid) {
+char *pid2name(pid_t pid)
+{
 	char proc_exe[1024];
 
 	if (!kill(pid, 0)) {
-		int delay=0;
+		int delay = 0;
 
 		sprintf(proc_exe, "/proc/%d/exe", pid);
 
-		while(delay<MAX_DELAY) {
+		while (delay < MAX_DELAY) {
 			if (!access(proc_exe, F_OK)) {
 				return strdup(proc_exe);
 			}
