@@ -7,7 +7,7 @@ GElf_Addr arch_plt_sym_val(struct ltelf *lte, size_t ndx, GElf_Rela * rela)
 	return rela->r_offset + 4;
 }
 
-void *plt2addr(struct process *proc, void **plt)
+void *sym2addr(struct process *proc, struct library_symbol *sym)
 {
-	return (void *)plt;
+	return sym->enter_addr;
 }
